==> vlc-debug-1:3.0.23-1-x86_64.pkg.tar.zst: usr/src/debug/vlc/vlc-b71bd03233a6a9392c906a22345041a9447bc49a/modules/gui/qt/network_qmlassets.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x2,0xb2,
  0x6d,
  0x6f,0x64,0x75,0x6c,0x65,0x20,0x56,0x4c,0x43,0x2e,0x4e,0x65,0x74,0x77,0x6f,0x72,
  0x6b,0xa,0x70,0x72,0x65,0x66,0x65,0x72,0x20,0x3a,0x2f,0x71,0x74,0x2f,0x71,0x6d,
  0x6c,0x2f,0x56,0x4c,0x43,0x2f,0x4e,0x65,0x74,0x77,0x6f,0x72,0x6b,0x2f,0xa,0x41,
  0x64,0x64,0x72,0x65,0x73,0x73,0x62,0x61,0x72,0x42,0x75,0x74,0x74,0x6f,0x6e,0x20,
  0x31,0x2e,0x30,0x20,0x41,0x64,0x64,0x72,0x65,0x73,0x73,0x62,0x61,0x72,0x42,0x75,
  0x74,0x74,0x6f,0x6e,0x2e,0x71,0x6d,0x6c,0xa,0x42,0x72,0x6f,0x77,0x73,0x65,0x44,
  0x65,0x76,0x69,0x63,0x65,0x56,0x69,0x65,0x77,0x20,0x31,0x2e,0x30,0x20,0x42,0x72,
  0x6f,0x77,0x73,0x65,0x44,0x65,0x76,0x69,0x63,0x65,0x56,0x69,0x65,0x77,0x2e,0x71,
  0x6d,0x6c,0xa,0x42,0x72,0x6f,0x77,0x73,0x65,0x44,0x69,0x73,0x70,0x6c,0x61,0x79,
  0x20,0x31,0x2e,0x30,0x20,0x42,0x72,0x6f,0x77,0x73,0x65,0x44,0x69,0x73,0x70,0x6c,
  0x61,0x79,0x2e,0x71,0x6d,0x6c,0xa,0x42,0x72,0x6f,0x77,0x73,0x65,0x48,0x6f,0x6d,
  0x65,0x44,0x69,0x73,0x70,0x6c,0x61,0x79,0x20,0x31,0x2e,0x30,0x20,0x42,0x72,0x6f,
  0x77,0x73,0x65,0x48,0x6f,0x6d,0x65,0x44,0x69,0x73,0x70,0x6c,0x61,0x79,0x2e,0x71,
  0x6d,0x6c,0xa,0x42,0x72,0x6f,0x77,0x73,0x65,0x54,0x72,0x65,0x65,0x44,0x69,0x73,
  0x70,0x6c,0x61,0x79,0x20,0x31,0x2e,0x30,0x20,0x42,0x72,0x6f,0x77,0x73,0x65,0x54,
  0x72,0x65,0x65,0x44,0x69,0x73,0x70,0x6c,0x61,0x79,0x2e,0x71,0x6d,0x6c,0xa,0x42,
  0x72,0x6f,0x77,0x73,0x65,0x54,0x72,0x65,0x65,0x48,0x65,0x61,0x64,0x65,0x72,0x20,
  0x31,0x2e,0x30,0x20,0x42,0x72,0x6f,0x77,0x73,0x65,0x54,0x72,0x65,0x65,0x48,0x65,
  0x61,0x64,0x65,0x72,0x2e,0x71,0x6d,0x6c,0xa,0x44,0x69,0x73,0x63,0x6f,0x76,0x65,
  0x72,0x44,0x69,0x73,0x70,0x6c,0x61,0x79,0x20,0x31,0x2e,0x30,0x20,0x44,0x69,0x73,
  0x63,0x6f,0x76,0x65,0x72,0x44,0x69,0x73,0x70,0x6c,0x61,0x79,0x2e,0x71,0x6d,0x6c,
  0xa,0x44,0x69,0x73,0x63,0x6f,0x76,0x65,0x72,0x55,0x72,0x6c,0x44,0x69,0x73,0x70,
  0x6c,0x61,0x79,0x20,0x31,0x2e,0x30,0x20,0x44,0x69,0x73,0x63,0x6f,0x76,0x65,0x72,
  0x55,0x72,0x6c,0x44,0x69,0x73,0x70,0x6c,0x61,0x79,0x2e,0x71,0x6d,0x6c,0xa,0x4e,
  0x65,0x74,0x77,0x6f,0x72,0x6b,0x41,0x64,0x64,0x72,0x65,0x73,0x73,0x62,0x61,0x72,
  0x20,0x31,0x2e,0x30,0x20,0x4e,0x65,0x74,0x77,0x6f,0x72,0x6b,0x41,0x64,0x64,0x72,
  0x65,0x73,0x73,0x62,0x61,0x72,0x2e,0x71,0x6d,0x6c,0xa,0x4e,0x65,0x74,0x77,0x6f,
  0x72,0x6b,0x43,0x75,0x73,0x74,0x6f,0x6d,0x43,0x6f,0x76,0x65,0x72,0x20,0x31,0x2e,
  0x30,0x20,0x4e,0x65,0x74,0x77,0x6f,0x72,0x6b,0x43,0x75,0x73,0x74,0x6f,0x6d,0x43,
  0x6f,0x76,0x65,0x72,0x2e,0x71,0x6d,0x6c,0xa,0x4e,0x65,0x74,0x77,0x6f,0x72,0x6b,
  0x47,0x72,0x69,0x64,0x49,0x74,0x65,0x6d,0x20,0x31,0x2e,0x30,0x20,0x4e,0x65,0x74,
  0x77,0x6f,0x72,0x6b,0x47,0x72,0x69,0x64,0x49,0x74,0x65,0x6d,0x2e,0x71,0x6d,0x6c,
  0xa,0x4e,0x65,0x74,0x77,0x6f,0x72,0x6b,0x54,0x68,0x75,0x6d,0x62,0x6e,0x61,0x69,
  0x6c,0x49,0x74,0x65,0x6d,0x20,0x31,0x2e,0x30,0x20,0x4e,0x65,0x74,0x77,0x6f,0x72,
  0x6b,0x54,0x68,0x75,0x6d,0x62,0x6e,0x61,0x69,0x6c,0x49,0x74,0x65,0x6d,0x2e,0x71,
  0x6d,0x6c,0xa,0x53,0x65,0x72,0x76,0x69,0x63,0x65,0x73,0x48,0x6f,0x6d,0x65,0x44,
  0x69,0x73,0x70,0x6c,0x61,0x79,0x20,0x31,0x2e,0x30,0x20,0x53,0x65,0x72,0x76,0x69,
  0x63,0x65,0x73,0x48,0x6f,0x6d,0x65,0x44,0x69,0x73,0x70,0x6c,0x61,0x79,0x2e,0x71,
  0x6d,0x6c,0xa,0x53,0x65,0x72,0x76,0x69,0x63,0x65,0x73,0x4d,0x61,0x6e,0x61,0x67,
  0x65,0x20,0x31,0x2e,0x30,0x20,0x53,0x65,0x72,0x76,0x69,0x63,0x65,0x73,0x4d,0x61,
  0x6e,0x61,0x67,0x65,0x2e,0x71,0x6d,0x6c,0xa,0x53,0x65,0x72,0x76,0x69,0x63,0x65,
  0x73,0x53,0x6f,0x75,0x72,0x63,0x65,0x73,0x20,0x31,0x2e,0x30,0x20,0x53,0x65,0x72,
  0x76,0x69,0x63,0x65,0x73,0x53,0x6f,0x75,0x72,0x63,0x65,0x73,0x2e,0x71,0x6d,0x6c,
  0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // VLC
  0x0,0x3,
  0x0,0x0,0x5b,0x3,
  0x0,0x56,
  0x0,0x4c,0x0,0x43,
    // Network
  0x0,0x7,
  0x4,0xcb,0xe6,0x2b,
  0x0,0x4e,
  0x0,0x65,0x0,0x74,0x0,0x77,0x0,0x6f,0x0,0x72,0x0,0x6b,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9b,0x47,0xb4,0xf8,0x28,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9b,0x47,0xb4,0xf8,0x28,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9b,0x47,0xb4,0xf8,0x28,
  // :/qt/qml/VLC
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9b,0x47,0xb4,0xf8,0x28,
  // :/qt/qml/VLC/Network
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9b,0x47,0xb4,0xf8,0x28,
  // :/qt/qml/VLC/Network/qmldir
  0x0,0x0,0x0,0x36,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9b,0x47,0xb4,0xf8,0x28,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_network_assets)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_network_assets)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_network_assets)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_network_assets)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_network_assets)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_network_assets)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> vlc-debug-1:3.0.23-2-x86_64.pkg.tar.zst: usr/src/debug/vlc/vlc-b71bd03233a6a9392c906a22345041a9447bc49a/modules/gui/qt/network_qmlassets.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x2,0xb2,
  0x6d,
  0x6f,0x64,0x75,0x6c,0x65,0x20,0x56,0x4c,0x43,0x2e,0x4e,0x65,0x74,0x77,0x6f,0x72,
  0x6b,0xa,0x70,0x72,0x65,0x66,0x65,0x72,0x20,0x3a,0x2f,0x71,0x74,0x2f,0x71,0x6d,
  0x6c,0x2f,0x56,0x4c,0x43,0x2f,0x4e,0x65,0x74,0x77,0x6f,0x72,0x6b,0x2f,0xa,0x41,
  0x64,0x64,0x72,0x65,0x73,0x73,0x62,0x61,0x72,0x42,0x75,0x74,0x74,0x6f,0x6e,0x20,
  0x31,0x2e,0x30,0x20,0x41,0x64,0x64,0x72,0x65,0x73,0x73,0x62,0x61,0x72,0x42,0x75,
  0x74,0x74,0x6f,0x6e,0x2e,0x71,0x6d,0x6c,0xa,0x42,0x72,0x6f,0x77,0x73,0x65,0x44,
  0x65,0x76,0x69,0x63,0x65,0x56,0x69,0x65,0x77,0x20,0x31,0x2e,0x30,0x20,0x42,0x72,
  0x6f,0x77,0x73,0x65,0x44,0x65,0x76,0x69,0x63,0x65,0x56,0x69,0x65,0x77,0x2e,0x71,
  0x6d,0x6c,0xa,0x42,0x72,0x6f,0x77,0x73,0x65,0x44,0x69,0x73,0x70,0x6c,0x61,0x79,
  0x20,0x31,0x2e,0x30,0x20,0x42,0x72,0x6f,0x77,0x73,0x65,0x44,0x69,0x73,0x70,0x6c,
  0x61,0x79,0x2e,0x71,0x6d,0x6c,0xa,0x42,0x72,0x6f,0x77,0x73,0x65,0x48,0x6f,0x6d,
  0x65,0x44,0x69,0x73,0x70,0x6c,0x61,0x79,0x20,0x31,0x2e,0x30,0x20,0x42,0x72,0x6f,
  0x77,0x73,0x65,0x48,0x6f,0x6d,0x65,0x44,0x69,0x73,0x70,0x6c,0x61,0x79,0x2e,0x71,
  0x6d,0x6c,0xa,0x42,0x72,0x6f,0x77,0x73,0x65,0x54,0x72,0x65,0x65,0x44,0x69,0x73,
  0x70,0x6c,0x61,0x79,0x20,0x31,0x2e,0x30,0x20,0x42,0x72,0x6f,0x77,0x73,0x65,0x54,
  0x72,0x65,0x65,0x44,0x69,0x73,0x70,0x6c,0x61,0x79,0x2e,0x71,0x6d,0x6c,0xa,0x42,
  0x72,0x6f,0x77,0x73,0x65,0x54,0x72,0x65,0x65,0x48,0x65,0x61,0x64,0x65,0x72,0x20,
  0x31,0x2e,0x30,0x20,0x42,0x72,0x6f,0x77,0x73,0x65,0x54,0x72,0x65,0x65,0x48,0x65,
  0x61,0x64,0x65,0x72,0x2e,0x71,0x6d,0x6c,0xa,0x44,0x69,0x73,0x63,0x6f,0x76,0x65,
  0x72,0x44,0x69,0x73,0x70,0x6c,0x61,0x79,0x20,0x31,0x2e,0x30,0x20,0x44,0x69,0x73,
  0x63,0x6f,0x76,0x65,0x72,0x44,0x69,0x73,0x70,0x6c,0x61,0x79,0x2e,0x71,0x6d,0x6c,
  0xa,0x44,0x69,0x73,0x63,0x6f,0x76,0x65,0x72,0x55,0x72,0x6c,0x44,0x69,0x73,0x70,
  0x6c,0x61,0x79,0x20,0x31,0x2e,0x30,0x20,0x44,0x69,0x73,0x63,0x6f,0x76,0x65,0x72,
  0x55,0x72,0x6c,0x44,0x69,0x73,0x70,0x6c,0x61,0x79,0x2e,0x71,0x6d,0x6c,0xa,0x4e,
  0x65,0x74,0x77,0x6f,0x72,0x6b,0x41,0x64,0x64,0x72,0x65,0x73,0x73,0x62,0x61,0x72,
  0x20,0x31,0x2e,0x30,0x20,0x4e,0x65,0x74,0x77,0x6f,0x72,0x6b,0x41,0x64,0x64,0x72,
  0x65,0x73,0x73,0x62,0x61,0x72,0x2e,0x71,0x6d,0x6c,0xa,0x4e,0x65,0x74,0x77,0x6f,
  0x72,0x6b,0x43,0x75,0x73,0x74,0x6f,0x6d,0x43,0x6f,0x76,0x65,0x72,0x20,0x31,0x2e,
  0x30,0x20,0x4e,0x65,0x74,0x77,0x6f,0x72,0x6b,0x43,0x75,0x73,0x74,0x6f,0x6d,0x43,
  0x6f,0x76,0x65,0x72,0x2e,0x71,0x6d,0x6c,0xa,0x4e,0x65,0x74,0x77,0x6f,0x72,0x6b,
  0x47,0x72,0x69,0x64,0x49,0x74,0x65,0x6d,0x20,0x31,0x2e,0x30,0x20,0x4e,0x65,0x74,
  0x77,0x6f,0x72,0x6b,0x47,0x72,0x69,0x64,0x49,0x74,0x65,0x6d,0x2e,0x71,0x6d,0x6c,
  0xa,0x4e,0x65,0x74,0x77,0x6f,0x72,0x6b,0x54,0x68,0x75,0x6d,0x62,0x6e,0x61,0x69,
  0x6c,0x49,0x74,0x65,0x6d,0x20,0x31,0x2e,0x30,0x20,0x4e,0x65,0x74,0x77,0x6f,0x72,
  0x6b,0x54,0x68,0x75,0x6d,0x62,0x6e,0x61,0x69,0x6c,0x49,0x74,0x65,0x6d,0x2e,0x71,
  0x6d,0x6c,0xa,0x53,0x65,0x72,0x76,0x69,0x63,0x65,0x73,0x48,0x6f,0x6d,0x65,0x44,
  0x69,0x73,0x70,0x6c,0x61,0x79,0x20,0x31,0x2e,0x30,0x20,0x53,0x65,0x72,0x76,0x69,
  0x63,0x65,0x73,0x48,0x6f,0x6d,0x65,0x44,0x69,0x73,0x70,0x6c,0x61,0x79,0x2e,0x71,
  0x6d,0x6c,0xa,0x53,0x65,0x72,0x76,0x69,0x63,0x65,0x73,0x4d,0x61,0x6e,0x61,0x67,
  0x65,0x20,0x31,0x2e,0x30,0x20,0x53,0x65,0x72,0x76,0x69,0x63,0x65,0x73,0x4d,0x61,
  0x6e,0x61,0x67,0x65,0x2e,0x71,0x6d,0x6c,0xa,0x53,0x65,0x72,0x76,0x69,0x63,0x65,
  0x73,0x53,0x6f,0x75,0x72,0x63,0x65,0x73,0x20,0x31,0x2e,0x30,0x20,0x53,0x65,0x72,
  0x76,0x69,0x63,0x65,0x73,0x53,0x6f,0x75,0x72,0x63,0x65,0x73,0x2e,0x71,0x6d,0x6c,
  0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // VLC
  0x0,0x3,
  0x0,0x0,0x5b,0x3,
  0x0,0x56,
  0x0,0x4c,0x0,0x43,
    // Network
  0x0,0x7,
  0x4,0xcb,0xe6,0x2b,
  0x0,0x4e,
  0x0,0x65,0x0,0x74,0x0,0x77,0x0,0x6f,0x0,0x72,0x0,0x6b,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9b,0xa8,0xd7,0x80,0x30,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9b,0xa8,0xd7,0x80,0x30,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9b,0xa8,0xd7,0x80,0x30,
  // :/qt/qml/VLC
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9b,0xa8,0xd7,0x80,0x30,
  // :/qt/qml/VLC/Network
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9b,0xa8,0xd7,0x80,0x30,
  // :/qt/qml/VLC/Network/qmldir
  0x0,0x0,0x0,0x36,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9b,0xa8,0xd7,0x80,0x30,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_network_assets)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_network_assets)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_network_assets)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_network_assets)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_network_assets)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_network_assets)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
